/*
 * Copyright (c) Huawei Technologies Co., Ltd. 2020-2024. All rights reserved.
 */

#ifndef PERCEPTION_IMPL_TYPE_CAM2CAMPERCEPTIONSTRUCT_H
#define PERCEPTION_IMPL_TYPE_CAM2CAMPERCEPTIONSTRUCT_H

#include "impl_type_int32.h"
#include "impl_type_int8.h"
#include "impl_type_cameradrivingbuffer.h"
#include "impl_type_driverheader.h"

namespace perception {
struct Cam2CamPerceptionStruct {
    ::Int32 dataSize{ 0 };
    ::Int8 cameraId{ 0 };
    ::CameraDrivingBuffer *rawData{ nullptr };
    ::DriverHeader header;

    static bool IsPlane()
    {
        return false;
    }

    ::CameraDrivingBuffer* GetMbufPtr() const
    {
        return rawData;
    }

    void SetMbufPtr(::CameraDrivingBuffer *p)
    {
        rawData = p;
    }

    using IsDpRawDataTag = void;
    using IsEnumerableTag = void;
    template<typename F>
    void enumerate(F& fun)
    {
        fun(dataSize);
        fun(cameraId);
        fun(header);
    }

    template<typename F>
    void enumerate(F& fun) const
    {
        fun(dataSize);
        fun(cameraId);
        fun(header);
    }

    template<typename F>
    void enumerate_internal(F& fun)
    {
        fun("dataSize", dataSize);
        fun("cameraId", cameraId);
        fun("header", header);
    }

    template<typename F>
    void enumerate_internal(F& fun) const
    {
        fun("dataSize", dataSize);
        fun("cameraId", cameraId);
        fun("header", header);
    }

    friend bool operator==(const ::perception::Cam2CamPerceptionStruct& lhs, const ::perception::Cam2CamPerceptionStruct& rhs) noexcept
    {
        return (lhs.dataSize == rhs.dataSize) && (lhs.cameraId == rhs.cameraId) && (lhs.rawData == rhs.rawData) && (lhs.header == rhs.header);
    }
};
} // namespace perception


#endif // PERCEPTION_IMPL_TYPE_CAM2CAMPERCEPTIONSTRUCT_H
